import featureFlags from './featureFlags'
import {getPDE, initPDE} from './pdeFactory'

initPDE()

export async function runFeatureFlags() {
  const pde = await getPDE()

  const path = window.location.pathname

  featureFlags.forEach(
    ({handler = requiredHandler(), pageWhitelist = null}) => {
      if (Array.isArray(pageWhitelist)) {
        const shouldRunHandler = isValidPath({pageWhitelist, path})
        if (shouldRunHandler) handler(pde)
      } else {
        handler(pde)
      }
    }
  )
}

/**
 * Utils
 */
const isValidPath = ({pageWhitelist, path}) => {
  return Boolean(pageWhitelist.find(page => page.test(path)))
}

const requiredHandler = () => {
  throw new Error('An handler function is required to run the feature flags.')
}
